;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "outline-indent" "20250921.2109"
  "Folding text based on indentation (origami alternative)."
  '((emacs "26.1"))
  :url "https://github.com/jamescherti/outline-indent.el"
  :commit "c99cf257ab5c34cb894bdd6238be9dda9fce9e85"
  :revdesc "c99cf257ab5c"
  :keywords '("outlines"))
